@@ -2,7 +2,7 @@
 
 #' Extracts ABS time series data from local Excel spreadsheets and converts to long format.
 #'
-#' `read_abs_data()` is soft deprecated. Please consider using `read_abs_local()`
+#' `read_abs_data()` is soft deprecated and will be removed in a future version. Please use `read_abs_local()`
 #' to import and tidy locally-stored ABS time series spreadsheets, or
 #' `read_abs()` to download, import, and tidy time series spreadsheets from the ABS
 #' website.
@@ -23,7 +23,8 @@ read_abs_data <- function(path, sheet) {
   dat$value <- readr::parse_double(dat$`value`)
 
   .Deprecated(new = "read_abs_local()",
-              old = "read_abs_data()")
+              old = "read_abs_data()",
+              msg = "read_abs_data() is deprecated and will be removed in a future version. Please use read_abs_local().")
 
   return(dat)
 }
