@@ -29,7 +29,7 @@ test_that("Local file can be tidied and looks how we expect",{
 
 test_that("Local file can be tidied without metadata",{
 
-  no_meta <- read_abs_local(local_filename, path = local_path, metadata = FALSE)
+  no_meta <- read_abs_local(filenames = local_filename, path = local_path, metadata = FALSE)
   expect_is(no_meta, "data.frame")
 
 
@@ -56,7 +56,7 @@ test_that("tidy_abs() gives appropriate errors",{
 })
 
 test_that("Local file can be read",{
-  lfs_21 <- read_abs_local(local_filename, path = local_path)
+  lfs_21 <- read_abs_local(filenames = local_filename, path = local_path)
 
   expect_equal(length(colnames(lfs_21)), 12)
   expect_is(lfs_21$date, "Date")
@@ -70,6 +70,10 @@ test_that("read_abs_local() returns appropriate errors and messages",{
 
   expect_error(read_abs_local(filenames = 1), path = "../testdata")
 
+  expect_error(read_abs_local(path = "../empty"))
+
+  expect_error(read_abs_local(filenames = local_filename, path = local_path,
+                              metadata = "a"))
 
 })
 
@@ -110,6 +114,59 @@ test_that("read_abs() downloads, imports, and tidies a data frame",
             expect_gt(nrow(wpi_1), 1)
           })
 
+test_that("read_abs() gets a whole catalogue number",
+          {
+            skip_on_cran()
+
+            check_abs_site()
+
+            wpi_all <- read_abs("6345.0")
+
+            expect_is(wpi_all, "data.frame")
+
+            expect_equal(length(wpi_all), 12)
+
+            expect_gt(nrow(wpi_all), 55000)
+          })
+
+test_that("read_abs() works when retain_files = FALSE",
+          {
+            skip_on_cran()
+
+            check_abs_site()
+
+            wpi_7 <- read_abs("6345.0", tables = "7a", retain_files = FALSE)
+
+            expect_is(wpi_7, "data.frame")
+
+          })
+
+test_that("read_abs() works with series ID(s)", {
+
+  skip_on_cran()
+
+  check_abs_site()
+
+  cpi_1 <- read_abs(series_id = "A2325846C")
+
+  cpi_2 <- read_abs(series_id = c("A2325846C", "A2325841T"))
+
+  expect_is(cpi_1, "data.frame")
+
+  expect_is(cpi_2, "data.frame")
+
+  expect_length(cpi_1, 12)
+
+  expect_length(cpi_2, 12)
+
+})
+
+test_that("deprecated get_abs() function gives a warning message",
+          {
+            expect_warning(get_abs())
+
+          })
+
 
 test_that("Old read_abs_sdmx function works",{
 
@@ -126,20 +183,16 @@ test_that("Old read_abs_sdmx function works",{
 })
 
 
-test_that("get_abs() returns a warning as it's deprecated",{
-
-  skip_on_cran()
-
-  check_abs_site()
-
-  expect_message(wpi_get <- get_abs("6345.0", "7a"))
-
-})
-
 test_that("read_abs() returns appropriate errors and messages when given invalid input",{
 
   expect_error(read_abs(cat_no = NULL))
 
+  expect_error(read_abs("6202.0", 1, retain_files = NULL))
+
+  expect_message(read_abs("6345", 1))
+
+  expect_message(read_abs("6345.0"))
+
   expect_error(read_abs(cat_no = "6345.0", metadata = 1))
 
   skip_on_cran()
@@ -200,3 +253,50 @@ test_that("Old read_abs_metadata() function imports a spreadsheet",{
   expect_equal(length(colnames(local_file)), 9)
 
 })
+
+
+test_that("read_cpi() function downloads CPI index numbers",{
+  skip_on_cran()
+
+  check_abs_site()
+
+  cpi <- read_cpi()
+
+  expect_is(cpi, "data.frame")
+
+  expect_equal(length(cpi), 2)
+
+  expect_is(cpi$date, "Date")
+
+  expect_is(cpi$cpi, "numeric")
+
+})
+
+test_that("read_cpi() returns appropriate errors",{
+
+  skip_on_cran()
+
+  check_abs_site()
+
+  expect_error(read_cpi(retain_files = NULL))
+
+  expect_error(read_cpi(show_progress_bars = NULL))
+
+  expect_error(read_cpi(retain_files = TRUE, path = 1))
+
+})
+
+test_that("separate_series() performs as expected",{
+
+ skip_on_cran()
+
+ check_abs_site()
+
+ motor_vehicles <- read_abs("9314.0") %>% separate_series()
+
+ expect_equal(14, length(motor_vehicles))
+
+ expect_equal(9, length(unique(motor_vehicles$series_1)))
+
+})
+
